==> share-file-systems-0.2.20.tgz: package/js/lib/terminal/test/application/browserUtilities/inviteConfirm.js <==
/* lib/terminal/test/application/browserUtilities/inviteConfirm - A test generator for accepting an invitation. */ const inviteConfirm = function terminal_test_application_browserUtilities_inviteConfirm(from, to, type) {
    // accept invitation
    return {
        delay: {
            node: [
                [
                    "getElementById",
                    type,
                    null
                ],
                [
                    "getElementsByTagName",
                    "li",
                    type === "device" ? 2 : 1
                ],
                [
                    "getElementsByTagName",
                    "button",
                    0
                ]
            ],
            qualifier: "is",
            target: [
                "lastChild",
                "textContent"
            ],
            type: "property",
            value: ` ${from === "self" ? "User-self" : from}`
        },
        interaction: [
            {
                event: "click",
                node: [
                    [
                        "getModalsByModalType",
                        "invite-accept",
                        0
                    ],
                    [
                        "getElementsByClassName",
                        "confirm",
                        0
                    ]
                ]
            }
        ],
        machine: to,
        name: `On ${to} accept ${type} invitation from ${from}`,
        unit: [
            {
                node: [
                    [
                        "getModalsByModalType",
                        "invite-accept",
                        0
                    ]
                ],
                qualifier: "is",
                target: [],
                type: "element",
                value: undefined
            }
        ]
    };
};
export default inviteConfirm;

==> share-file-systems-0.4.1.tgz: package/js/lib/terminal/test/application/browserUtilities/inviteConfirm.js <==
/* lib/terminal/test/application/browserUtilities/inviteConfirm - A test generator for accepting an invitation. */ const inviteConfirm = function terminal_test_application_browserUtilities_inviteConfirm(from, to, type) {
    // accept invitation
    return {
        delay: {
            node: [
                [
                    "getElementById",
                    type,
                    null
                ],
                [
                    "getElementsByTagName",
                    "li",
                    type === "device" ? from === "self" && to === "VM1" ? 3 : 2 : 1
                ],
                [
                    "getElementsByTagName",
                    "button",
                    0
                ]
            ],
            qualifier: "is",
            target: [
                "lastChild",
                "textContent"
            ],
            type: "property",
            value: ` ${from === "self" ? type === "device" ? "Primary Device" : "User-self" : from}`
        },
        interaction: [
            {
                event: "click",
                node: [
                    [
                        "getModalsByModalType",
                        "invite-ask",
                        0
                    ],
                    [
                        "getElementsByClassName",
                        "confirm",
                        0
                    ]
                ]
            }
        ],
        machine: to,
        name: `On ${to} accept ${type} invitation from ${from}`,
        unit: [
            {
                node: [
                    [
                        "getModalsByModalType",
                        "invite-ask",
                        0
                    ]
                ],
                qualifier: "is",
                target: [],
                type: "element",
                value: undefined
            }
        ]
    };
};
export default inviteConfirm;
